/* Driver template for the LEMON parser generator.
** The author disclaims copyright to this source code.
*/
/* First off, code is included which follows the "include" declaration
** in the input file. */
#include <stdio.h>
#include <string.h>
#include <assert.h>

#ifdef _MSC_VER
#define CDECL __cdecl
#else
#define CDECL
#endif

/* Next is all token values, in a form suitable for use by makeheaders.
** This section will be null unless lemon is run with the -m switch.
*/
/* 
** These constants (all generated automatically by the parser generator)
** specify the various kinds of tokens (terminals) that the parser
** understands. 
**
** Each symbol here is a terminal symbol in the grammar.
*/
/* Make sure the INTERFACE macro is defined.
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/* The next thing included is series of defines which control
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 terminals
**                       and nonterminals.  "int" is used otherwise.
**    YYNOCODE           is a number of type YYCODETYPE which corresponds
**                       to no legal terminal or nonterminal number.  This
**                       number is used to fill in empty slots of the hash 
**                       table.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       have fall-back values which should be used if the
**                       original value of the token will not parse.
**    YYACTIONTYPE       is the data type used for storing terminal
**                       and nonterminal numbers.  "unsigned char" is
**                       used if there are fewer than 250 rules and
**                       states combined.  "int" is used otherwise.
**    XlatParseTOKENTYPE     is the data type used for minor tokens given 
**                       directly to the parser from the tokenizer.
**    YYMINORTYPE        is the data type used for all minor tokens.
**                       This is typically a union of many types, one of
**                       which is XlatParseTOKENTYPE.  The entry in the union
**                       for base tokens is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    XlatParseARG_SDECL     A static variable declaration for the %extra_argument
**    XlatParseARG_PDECL     A parameter declaration for the %extra_argument
**    XlatParseARG_STORE     Code to store %extra_argument into yypParser
**    XlatParseARG_FETCH     Code to extract %extra_argument from yypParser
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
*/
#define YYCODETYPE unsigned char
#define YYNOCODE 63
#define YYACTIONTYPE unsigned char
#define XlatParseTOKENTYPE FParseToken
typedef union {
  XlatParseTOKENTYPE yy0;
  ListFilter yy3;
  ParseBoomArg yy7;
  MoreFilters * yy51;
  int yy68;
  FBoomArg yy82;
  SpecialArgs yy87;
  MoreLines * yy93;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define XlatParseARG_SDECL  FParseContext *context ;
#define XlatParseARG_PDECL , FParseContext *context 
#define XlatParseARG_FETCH  FParseContext *context  = yypParser->context 
#define XlatParseARG_STORE yypParser->context  = context 
#define YYNSTATE 156
#define YYNRULE 81
#define YY_NO_ACTION      (YYNSTATE+YYNRULE+2)
#define YY_ACCEPT_ACTION  (YYNSTATE+YYNRULE+1)
#define YY_ERROR_ACTION   (YYNSTATE+YYNRULE)

/* Next are that tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N < YYNSTATE                  Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   YYNSTATE <= N < YYNSTATE+YYNRULE   Reduce by rule N-YYNSTATE.
**
**   N == YYNSTATE+YYNRULE              A syntax error has occurred.
**
**   N == YYNSTATE+YYNRULE+1            The parser accepts its input.
**
**   N == YYNSTATE+YYNRULE+2            No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as
**
**      yy_action[ yy_shift_ofst[S] + X ]
**
** If the index value yy_shift_ofst[S]+X is out of range or if the value
** yy_lookahead[yy_shift_ofst[S]+X] is not equal to X or if yy_shift_ofst[S]
** is equal to YY_SHIFT_USE_DFLT, it means that the action is not in the table
** and that yy_default[S] should be used instead.  
**
** The formula above is for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
*/
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    21,   25,   44,   34,   36,   24,   19,  156,  116,   27,
 /*    10 */    24,   19,   27,  126,  114,   29,  133,  114,   29,   51,
 /*    20 */    94,   27,  127,   98,  106,   58,  114,   29,   20,  151,
 /*    30 */    93,  108,   56,  112,  154,  155,  103,   95,   84,   13,
 /*    40 */   148,  147,  146,  139,  137,  134,  123,  118,   77,    9,
 /*    50 */    21,   25,   44,   34,   36,   24,   19,   21,   25,   44,
 /*    60 */    34,   36,   24,   19,   21,   25,   44,   34,   36,   24,
 /*    70 */    19,  238,    1,   28,   44,   34,   36,   24,   19,  141,
 /*    80 */     8,  111,  110,    5,   21,   25,   44,   34,   36,   24,
 /*    90 */    19,   21,   25,   44,   34,   36,   24,   19,   69,  122,
 /*   100 */    45,   78,   99,   21,   25,   44,   34,   36,   24,   19,
 /*   110 */    21,   25,   44,   34,   36,   24,   19,  143,   38,   43,
 /*   120 */    25,   44,   34,   36,   24,   19,   18,   89,  120,   21,
 /*   130 */    25,   44,   34,   36,   24,   19,   50,    3,  109,  107,
 /*   140 */    65,   22,   21,   25,   44,   34,   36,   24,   19,   21,
 /*   150 */    25,   44,   34,   36,   24,   19,   57,  113,   30,  128,
 /*   160 */   129,  130,  131,  132,   67,   31,  121,   59,   21,   25,
 /*   170 */    44,   34,   36,   24,   19,   21,   25,   44,   34,   36,
 /*   180 */    24,   19,   69,   60,   14,  142,   97,   21,   25,   44,
 /*   190 */    34,   36,   24,   19,   21,   25,   44,   34,   36,   24,
 /*   200 */    19,   55,   48,    6,   50,    3,  152,  102,  125,   88,
 /*   210 */    21,   25,   44,   34,   36,   24,   19,   21,   25,   44,
 /*   220 */    34,   36,   24,   19,    2,   27,   35,  145,   71,   33,
 /*   230 */   114,   29,   85,   16,  105,   46,   21,   25,   44,   34,
 /*   240 */    36,   24,   19,   21,   25,   44,   34,   36,   24,   19,
 /*   250 */    27,   64,   37,   23,   61,  114,   29,   49,   66,  100,
 /*   260 */    32,    7,   10,   21,   25,   44,   34,   36,   24,   19,
 /*   270 */    21,   25,   44,   34,   36,   24,   19,  138,   52,   17,
 /*   280 */    34,   36,   24,   19,  153,   62,   39,  119,   42,   21,
 /*   290 */    25,   44,   34,   36,   24,   19,   21,   25,   44,   34,
 /*   300 */    36,   24,   19,   27,  144,   15,   58,   68,  114,   29,
 /*   310 */    40,   93,  124,   11,   12,   82,   21,   25,   44,   34,
 /*   320 */    36,   24,   19,   92,    4,   70,  135,   90,   26,   21,
 /*   330 */    25,   44,   34,   36,   24,   19,   21,   25,   44,   34,
 /*   340 */    36,   24,   19,   21,   25,   44,   34,   36,   24,   19,
 /*   350 */    21,   25,   44,   34,   36,   24,   19,   27,  136,   47,
 /*   360 */    81,   27,  114,   29,   27,  150,  114,   29,   27,  114,
 /*   370 */    29,   91,   96,  114,   29,   27,  104,   75,   74,  149,
 /*   380 */   114,   29,   76,  239,   79,   73,   53,  140,   63,   87,
 /*   390 */   101,  115,   54,   83,   86,   72,  117,   41,   80,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     2,    3,    4,    5,    6,    7,    8,    0,    1,    5,
 /*    10 */     7,    8,    5,   19,   10,   11,   15,   10,   11,   18,
 /*    20 */    13,    5,   28,   16,   20,   49,   10,   11,   21,   31,
 /*    30 */    54,   55,   49,   35,   36,   37,   20,   30,   49,   32,
 /*    40 */    41,   42,   43,   44,   45,   46,   47,   48,   49,   50,
 /*    50 */     2,    3,    4,    5,    6,    7,    8,    2,    3,    4,
 /*    60 */     5,    6,    7,    8,    2,    3,    4,    5,    6,    7,
 /*    70 */     8,   39,   40,   18,    4,    5,    6,    7,    8,   31,
 /*    80 */    57,   33,   14,   21,    2,    3,    4,    5,    6,    7,
 /*    90 */     8,    2,    3,    4,    5,    6,    7,    8,   49,   52,
 /*   100 */    18,   49,   53,    2,    3,    4,    5,    6,    7,    8,
 /*   110 */     2,    3,    4,    5,    6,    7,    8,   31,   29,   18,
 /*   120 */     3,    4,    5,    6,    7,    8,   18,   51,   52,    2,
 /*   130 */     3,    4,    5,    6,    7,    8,   58,   59,   60,   12,
 /*   140 */    49,   19,    2,    3,    4,    5,    6,    7,    8,    2,
 /*   150 */     3,    4,    5,    6,    7,    8,   49,   15,   18,   23,
 /*   160 */    24,   25,   26,   27,   49,   18,   22,   49,    2,    3,
 /*   170 */     4,    5,    6,    7,    8,    2,    3,    4,    5,    6,
 /*   180 */     7,    8,   49,   49,   18,   12,   53,    2,    3,    4,
 /*   190 */     5,    6,    7,    8,    2,    3,    4,    5,    6,    7,
 /*   200 */     8,   49,   18,   11,   58,   59,   60,   22,   56,   49,
 /*   210 */     2,    3,    4,    5,    6,    7,    8,    2,    3,    4,
 /*   220 */     5,    6,    7,    8,   17,    5,   18,   31,   49,   18,
 /*   230 */    10,   11,   49,   18,   14,   18,    2,    3,    4,    5,
 /*   240 */     6,    7,    8,    2,    3,    4,    5,    6,    7,    8,
 /*   250 */     5,   49,   18,   11,   49,   10,   11,   18,   49,   14,
 /*   260 */    19,   11,   49,    2,    3,    4,    5,    6,    7,    8,
 /*   270 */     2,    3,    4,    5,    6,    7,    8,   12,   49,   18,
 /*   280 */     5,    6,    7,    8,   31,   49,   18,   17,   61,    2,
 /*   290 */     3,    4,    5,    6,    7,    8,    2,    3,    4,    5,
 /*   300 */     6,    7,    8,    5,   12,   18,   49,   49,   10,   11,
 /*   310 */    19,   54,   55,   19,   18,   49,    2,    3,    4,    5,
 /*   320 */     6,    7,    8,   14,   18,   49,   12,   49,   11,    2,
 /*   330 */     3,    4,    5,    6,    7,    8,    2,    3,    4,    5,
 /*   340 */     6,    7,    8,    2,    3,    4,    5,    6,    7,    8,
 /*   350 */     2,    3,    4,    5,    6,    7,    8,    5,   31,   18,
 /*   360 */    49,    5,   10,   11,    5,   31,   10,   11,    5,   10,
 /*   370 */    11,   49,   20,   10,   11,    5,   20,   49,   49,   20,
 /*   380 */    10,   11,   49,   62,   49,   49,   49,   49,   49,   49,
 /*   390 */    20,   49,   49,   49,   49,   49,   49,   34,   49,
};
#define YY_SHIFT_USE_DFLT (-7)
#define YY_SHIFT_MAX 112
static const short yy_shift_ofst[] = {
 /*     0 */    -7,    7,  136,  136,  298,  298,  352,  352,  298,   68,
 /*    10 */    -2,  220,  356,  363,  245,    4,   16,  370,  359,  298,
 /*    20 */   298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
 /*    30 */   298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
 /*    40 */   298,  298,  298,  298,  298,  298,  298,  298,  298,  298,
 /*    50 */    -6,   68,   48,  127,   55,   62,  341,   82,   89,  101,
 /*    60 */   108,  334,  327,  314,  294,  287,  268,  261,  234,  215,
 /*    70 */   208,  192,  185,  173,  166,  147,  140,  241,  348,  348,
 /*    80 */   348,  348,  348,  348,  348,  348,  117,   70,  275,    1,
 /*    90 */     3,    3,  317,  306,  309,  291,  296,  292,  270,  265,
 /*   100 */   250,  239,  242,  217,  211,  196,  184,  207,  144,  142,
 /*   110 */   122,   86,  253,
};
#define YY_REDUCE_USE_DFLT (-25)
#define YY_REDUCE_MAX 51
static const short yy_reduce_ofst[] = {
 /*     0 */    32,   -1,   78,  146,  257,  -24,  133,   49,  152,   76,
 /*    10 */   227,  229,  209,  202,  179,  134,  115,   91,  349,  347,
 /*    20 */   346,  345,  344,  343,  342,  340,  339,  338,  337,  336,
 /*    30 */   335,  333,  329,  328,  322,  311,  278,  276,  266,  258,
 /*    40 */   236,  213,  205,  183,  160,  118,  107,   52,  -11,  -17,
 /*    50 */    23,   47,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */   157,  237,  213,  213,  237,  237,  187,  187,  237,  180,
 /*    10 */   237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
 /*    20 */   237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
 /*    30 */   237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
 /*    40 */   237,  237,  237,  237,  237,  237,  237,  237,  237,  237,
 /*    50 */   237,  237,  237,  237,  237,  223,  207,  203,  237,  204,
 /*    60 */   200,  237,  237,  237,  237,  199,  189,  198,  190,  197,
 /*    70 */   191,  237,  237,  237,  237,  194,  195,  237,  208,  196,
 /*    80 */   201,  192,  227,  184,  210,  205,  172,  174,  173,  237,
 /*    90 */   168,  169,  237,  225,  237,  237,  188,  237,  237,  237,
 /*   100 */   237,  206,  237,  202,  193,  237,  209,  237,  237,  237,
 /*   110 */   183,  237,  237,  212,  167,  170,  166,  171,  165,  179,
 /*   120 */   181,  224,  182,  164,  226,  215,  221,  222,  216,  217,
 /*   130 */   218,  219,  220,  178,  163,  177,  228,  162,  186,  161,
 /*   140 */   175,  229,  176,  231,  185,  230,  160,  159,  158,  211,
 /*   150 */   232,  233,  214,  234,  235,  236,
};
#define YY_SZ_ACTTAB (int)(sizeof(yy_action)/sizeof(yy_action[0]))

/* The next table maps tokens into fallback tokens.  If a construct
** like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammer, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
*/
struct yyStackEntry {
  int stateno;       /* The state-number */
  int major;         /* The major token value.  This is the code
                     ** number for the token at this stack level */
  YYMINORTYPE minor; /* The user-supplied minor token value.  This
                     ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  int yyidx;                    /* Index of top element in stack */
  int yyerrcnt;                 /* Shifts left before out of the error */
  XlatParseARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void XlatParseTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "NOP",           "OR",            "XOR",         
  "AND",           "MINUS",         "PLUS",          "MULTIPLY",    
  "DIVIDE",        "NEG",           "NUM",           "LPAREN",      
  "RPAREN",        "DEFINE",        "SYM",           "RBRACE",      
  "ENUM",          "LBRACE",        "COMMA",         "EQUALS",      
  "TAG",           "LBRACKET",      "RBRACKET",      "FLAGS",       
  "ARG2",          "ARG3",          "ARG4",          "ARG5",        
  "OR_EQUAL",      "COLON",         "MAXLINESPECIAL",  "SEMICOLON",   
  "SECTOR",        "NOBITMASK",     "BITMASK",       "CLEAR",       
  "LSHASSIGN",     "RSHASSIGN",     "error",         "main",        
  "translation_unit",  "external_declaration",  "define_statement",  "enum_statement",
  "linetype_declaration",  "boom_declaration",  "sector_declaration",  "sector_bitmask",
  "maxlinespecial_def",  "exp",           "enum_open",     "enum_list",   
  "single_enum",   "special_args",  "list_val",      "arg_list",    
  "boom_args",     "boom_op",       "boom_selector",  "boom_line",   
  "boom_body",     "sector_op",   
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "main ::= translation_unit",
 /*   1 */ "translation_unit ::=",
 /*   2 */ "translation_unit ::= translation_unit external_declaration",
 /*   3 */ "external_declaration ::= define_statement",
 /*   4 */ "external_declaration ::= enum_statement",
 /*   5 */ "external_declaration ::= linetype_declaration",
 /*   6 */ "external_declaration ::= boom_declaration",
 /*   7 */ "external_declaration ::= sector_declaration",
 /*   8 */ "external_declaration ::= sector_bitmask",
 /*   9 */ "external_declaration ::= maxlinespecial_def",
 /*  10 */ "external_declaration ::= NOP",
 /*  11 */ "exp ::= NUM",
 /*  12 */ "exp ::= exp PLUS exp",
 /*  13 */ "exp ::= exp MINUS exp",
 /*  14 */ "exp ::= exp MULTIPLY exp",
 /*  15 */ "exp ::= exp DIVIDE exp",
 /*  16 */ "exp ::= exp OR exp",
 /*  17 */ "exp ::= exp AND exp",
 /*  18 */ "exp ::= exp XOR exp",
 /*  19 */ "exp ::= MINUS exp",
 /*  20 */ "exp ::= LPAREN exp RPAREN",
 /*  21 */ "define_statement ::= DEFINE SYM LPAREN exp RPAREN",
 /*  22 */ "enum_statement ::= enum_open enum_list RBRACE",
 /*  23 */ "enum_open ::= ENUM LBRACE",
 /*  24 */ "enum_list ::=",
 /*  25 */ "enum_list ::= single_enum",
 /*  26 */ "enum_list ::= enum_list COMMA single_enum",
 /*  27 */ "single_enum ::= SYM",
 /*  28 */ "single_enum ::= SYM EQUALS exp",
 /*  29 */ "linetype_declaration ::= exp EQUALS exp COMMA exp LPAREN special_args RPAREN",
 /*  30 */ "linetype_declaration ::= exp EQUALS exp COMMA SYM LPAREN special_args RPAREN",
 /*  31 */ "special_args ::=",
 /*  32 */ "special_args ::= TAG",
 /*  33 */ "special_args ::= TAG COMMA exp",
 /*  34 */ "special_args ::= TAG COMMA exp COMMA exp",
 /*  35 */ "special_args ::= TAG COMMA exp COMMA exp COMMA exp",
 /*  36 */ "special_args ::= TAG COMMA exp COMMA exp COMMA exp COMMA exp",
 /*  37 */ "special_args ::= TAG COMMA TAG",
 /*  38 */ "special_args ::= TAG COMMA TAG COMMA exp",
 /*  39 */ "special_args ::= TAG COMMA TAG COMMA exp COMMA exp",
 /*  40 */ "special_args ::= TAG COMMA TAG COMMA exp COMMA exp COMMA exp",
 /*  41 */ "special_args ::= exp",
 /*  42 */ "special_args ::= exp COMMA exp",
 /*  43 */ "special_args ::= exp COMMA exp COMMA exp",
 /*  44 */ "special_args ::= exp COMMA exp COMMA exp COMMA exp",
 /*  45 */ "special_args ::= exp COMMA exp COMMA exp COMMA exp COMMA exp",
 /*  46 */ "special_args ::= exp COMMA TAG",
 /*  47 */ "special_args ::= exp COMMA TAG COMMA exp",
 /*  48 */ "special_args ::= exp COMMA TAG COMMA exp COMMA exp",
 /*  49 */ "special_args ::= exp COMMA TAG COMMA exp COMMA exp COMMA exp",
 /*  50 */ "special_args ::= exp COMMA exp COMMA TAG",
 /*  51 */ "special_args ::= exp COMMA exp COMMA TAG COMMA exp",
 /*  52 */ "special_args ::= exp COMMA exp COMMA TAG COMMA exp COMMA exp",
 /*  53 */ "special_args ::= exp COMMA exp COMMA exp COMMA TAG",
 /*  54 */ "special_args ::= exp COMMA exp COMMA exp COMMA TAG COMMA exp",
 /*  55 */ "special_args ::= exp COMMA exp COMMA exp COMMA exp COMMA TAG",
 /*  56 */ "boom_declaration ::= LBRACKET exp RBRACKET LPAREN exp COMMA exp RPAREN LBRACE boom_body RBRACE",
 /*  57 */ "boom_body ::=",
 /*  58 */ "boom_body ::= boom_line boom_body",
 /*  59 */ "boom_line ::= boom_selector boom_op boom_args",
 /*  60 */ "boom_selector ::= FLAGS",
 /*  61 */ "boom_selector ::= ARG2",
 /*  62 */ "boom_selector ::= ARG3",
 /*  63 */ "boom_selector ::= ARG4",
 /*  64 */ "boom_selector ::= ARG5",
 /*  65 */ "boom_op ::= EQUALS",
 /*  66 */ "boom_op ::= OR_EQUAL",
 /*  67 */ "boom_args ::= exp",
 /*  68 */ "boom_args ::= exp LBRACKET arg_list RBRACKET",
 /*  69 */ "arg_list ::= list_val",
 /*  70 */ "arg_list ::= list_val COMMA arg_list",
 /*  71 */ "list_val ::= exp COLON exp",
 /*  72 */ "maxlinespecial_def ::= MAXLINESPECIAL EQUALS exp SEMICOLON",
 /*  73 */ "sector_declaration ::= SECTOR exp EQUALS exp SEMICOLON",
 /*  74 */ "sector_declaration ::= SECTOR exp EQUALS SYM SEMICOLON",
 /*  75 */ "sector_declaration ::= SECTOR exp EQUALS exp NOBITMASK SEMICOLON",
 /*  76 */ "sector_bitmask ::= SECTOR BITMASK exp sector_op exp SEMICOLON",
 /*  77 */ "sector_bitmask ::= SECTOR BITMASK exp SEMICOLON",
 /*  78 */ "sector_bitmask ::= SECTOR BITMASK exp CLEAR SEMICOLON",
 /*  79 */ "sector_op ::= LSHASSIGN",
 /*  80 */ "sector_op ::= RSHASSIGN",
};
#endif /* NDEBUG */

#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.
*/
static void yyGrowStack(yyParser *p){
  int newSize;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  if( pNew ){
    p->yystack = pNew;
    p->yystksz = newSize;
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows to %d entries!\n",
              yyTracePrompt, p->yystksz);
    }
#endif
  }
}
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to XlatParse and XlatParseFree.
*/
void *XlatParseAlloc(void *(CDECL *mallocProc)(size_t)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (size_t)sizeof(yyParser) );
  if( pParser ){
    pParser->yyidx = -1;
#if YYSTACKDEPTH<=0
    yyGrowStack(pParser);
#endif
  }
  return pParser;
}

/* The following function deletes the value associated with a
** symbol.  The symbol can be either a terminal or nonterminal.
** "yymajor" is the symbol code, and "yypminor" is a pointer to
** the value.
*/
static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are not used
    ** inside the C code.
    */
    case 1: /* NOP */
    case 2: /* OR */
    case 3: /* XOR */
    case 4: /* AND */
    case 5: /* MINUS */
    case 6: /* PLUS */
    case 7: /* MULTIPLY */
    case 8: /* DIVIDE */
    case 9: /* NEG */
    case 10: /* NUM */
    case 11: /* LPAREN */
    case 12: /* RPAREN */
    case 13: /* DEFINE */
    case 14: /* SYM */
    case 15: /* RBRACE */
    case 16: /* ENUM */
    case 17: /* LBRACE */
    case 18: /* COMMA */
    case 19: /* EQUALS */
    case 20: /* TAG */
    case 21: /* LBRACKET */
    case 22: /* RBRACKET */
    case 23: /* FLAGS */
    case 24: /* ARG2 */
    case 25: /* ARG3 */
    case 26: /* ARG4 */
    case 27: /* ARG5 */
    case 28: /* OR_EQUAL */
    case 29: /* COLON */
    case 30: /* MAXLINESPECIAL */
    case 31: /* SEMICOLON */
    case 32: /* SECTOR */
    case 33: /* NOBITMASK */
    case 34: /* BITMASK */
    case 35: /* CLEAR */
    case 36: /* LSHASSIGN */
    case 37: /* RSHASSIGN */
#line 4 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{}
#line 567 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
      break;
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
**
** Return the major token number for the symbol popped.
*/
static int yy_pop_parser_stack(yyParser *pParser){
  YYCODETYPE yymajor;
  yyStackEntry *yytos = &pParser->yystack[pParser->yyidx];

  if( pParser->yyidx<0 ) return 0;
#ifndef NDEBUG
  if( yyTraceFILE && pParser->yyidx>=0 ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yymajor = yytos->major;
  yy_destructor( yymajor, &yytos->minor);
  pParser->yyidx--;
  return yymajor;
}

/* 
** Deallocate and destroy a parser.  Destructors are all called for
** all stack elements before shutting the parser down.
**
** Inputs:
** <ul>
** <li>  A pointer to the parser.  This should be a pointer
**       obtained from XlatParseAlloc.
** <li>  A pointer to a function used to reclaim memory obtained
**       from malloc.
** </ul>
*/
void XlatParseFree(
  void *p,                    /* The parser to be deleted */
  void (CDECL *freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
  if( pParser==0 ) return;
  while( pParser->yyidx>=0 ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yystack[pParser->yyidx].stateno;
 
  if( stateno>YY_SHIFT_MAX || (i = yy_shift_ofst[stateno])==YY_SHIFT_USE_DFLT ){
    return yy_default[stateno];
  }
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_SZ_ACTTAB || yy_lookahead[i]!=iLookAhead ){
    if( iLookAhead>0 ){
#ifdef YYFALLBACK
      int iFallback;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        return yy_find_shift_action(pParser, iFallback);
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( j>=0 && j<YY_SZ_ACTTAB && yy_lookahead[j]==YYWILDCARD ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
    }
    return yy_default[stateno];
  }else{
    return yy_action[i];
  }
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
**
** If the look-ahead token is YYNOCODE, then check to see if the action is
** independent of the look-ahead.  If it is, return the action, otherwise
** return YY_NO_ACTION.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  if( stateno>YY_REDUCE_MAX ||
	  (i = yy_reduce_ofst[stateno])==YY_REDUCE_USE_DFLT ){
	return yy_default[stateno];
  }
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
  if( i<0 || i>=YY_SZ_ACTTAB || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }else{
	return yy_action[i];
  }
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser, YYMINORTYPE *yypMinor){
   XlatParseARG_FETCH;
   yypParser->yyidx--;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
   XlatParseARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  YYMINORTYPE *yypMinor         /* Pointer ot the minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yyidx++;
#if YYSTACKDEPTH>0
  if( yypParser->yyidx>=YYSTACKDEPTH ){
    yyStackOverflow(yypParser, yypMinor);
    return;
  }
#else
  if( yypParser->yyidx>=yypParser->yystksz ){
    yyGrowStack(yypParser);
    if( yypParser->yyidx>=yypParser->yystksz ){
      yyStackOverflow(yypParser, yypMinor);
      return;
    }
  }
#endif
  yytos = &yypParser->yystack[yypParser->yyidx];
  yytos->stateno = yyNewState;
  yytos->major = yyMajor;
  yytos->minor = *yypMinor;
#ifndef NDEBUG
  if( yyTraceFILE && yypParser->yyidx>0 ){
    int i;
    fprintf(yyTraceFILE,"%sShift %d\n",yyTracePrompt,yyNewState);
    fprintf(yyTraceFILE,"%sStack:",yyTracePrompt);
    for(i=1; i<=yypParser->yyidx; i++)
      fprintf(yyTraceFILE," (%d)%s",yypParser->yystack[i].stateno,yyTokenName[yypParser->yystack[i].major]);
    fprintf(yyTraceFILE,"\n");
  }
#endif
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 39, 1 },
  { 40, 0 },
  { 40, 2 },
  { 41, 1 },
  { 41, 1 },
  { 41, 1 },
  { 41, 1 },
  { 41, 1 },
  { 41, 1 },
  { 41, 1 },
  { 41, 1 },
  { 49, 1 },
  { 49, 3 },
  { 49, 3 },
  { 49, 3 },
  { 49, 3 },
  { 49, 3 },
  { 49, 3 },
  { 49, 3 },
  { 49, 2 },
  { 49, 3 },
  { 42, 5 },
  { 43, 3 },
  { 50, 2 },
  { 51, 0 },
  { 51, 1 },
  { 51, 3 },
  { 52, 1 },
  { 52, 3 },
  { 44, 8 },
  { 44, 8 },
  { 53, 0 },
  { 53, 1 },
  { 53, 3 },
  { 53, 5 },
  { 53, 7 },
  { 53, 9 },
  { 53, 3 },
  { 53, 5 },
  { 53, 7 },
  { 53, 9 },
  { 53, 1 },
  { 53, 3 },
  { 53, 5 },
  { 53, 7 },
  { 53, 9 },
  { 53, 3 },
  { 53, 5 },
  { 53, 7 },
  { 53, 9 },
  { 53, 5 },
  { 53, 7 },
  { 53, 9 },
  { 53, 7 },
  { 53, 9 },
  { 53, 9 },
  { 45, 11 },
  { 60, 0 },
  { 60, 2 },
  { 59, 3 },
  { 58, 1 },
  { 58, 1 },
  { 58, 1 },
  { 58, 1 },
  { 58, 1 },
  { 57, 1 },
  { 57, 1 },
  { 56, 1 },
  { 56, 4 },
  { 55, 1 },
  { 55, 3 },
  { 54, 3 },
  { 48, 4 },
  { 46, 5 },
  { 46, 5 },
  { 46, 6 },
  { 47, 6 },
  { 47, 4 },
  { 47, 5 },
  { 61, 1 },
  { 61, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  int yyruleno                 /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  YYMINORTYPE yygotominor;        /* The LHS of the rule reduced */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  XlatParseARG_FETCH;
  yymsp = &yypParser->yystack[yypParser->yyidx];
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno>=0 
        && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    fprintf(yyTraceFILE, "%sReduce [%s].\n", yyTracePrompt,
      yyRuleName[yyruleno]);
  }
#endif /* NDEBUG */

  /* Silence complaints from purify about yygotominor being uninitialized
  ** in some cases when it is copied into the stack after the following
  ** switch.  yygotominor is uninitialized when a rule reduces that does
  ** not set the value of its left-hand side nonterminal.  Leaving the
  ** value of the nonterminal uninitialized is utterly harmless as long
  ** as the value is never used.  So really the only thing this code
  ** accomplishes is to quieten purify.  
  **
  ** 2007-01-16:  The wireshark project (www.wireshark.org) reports that
  ** without this code, their parser segfaults.  I'm not sure what there
  ** parser is doing to make this happen.  This is the second bug report
  ** from wireshark this week.  Clearly they are stressing Lemon in ways
  ** that it has not been previously stressed...  (SQLite ticket #2172)
  */
  memset(&yygotominor, 0, sizeof(yygotominor));


  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
      case 0: /* main ::= translation_unit */
      case 1: /*translation_unit ::= */
      case 2: /*translation_unit ::= translation_unit external_declaration */
      case 3: /*external_declaration ::= define_statement */
      case 4: /*external_declaration ::= enum_statement */
      case 5: /*external_declaration ::= linetype_declaration */
      case 6: /*external_declaration ::= boom_declaration */
      case 7: /*external_declaration ::= sector_declaration */
      case 8: /*external_declaration ::= sector_bitmask */
      case 9: /*external_declaration ::= maxlinespecial_def */
      case 24: /*enum_list ::= */
      case 25: /*enum_list ::= single_enum */
#line 10 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
}
#line 922 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 10: /* external_declaration ::= NOP */
#line 22 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
  yy_destructor(1,&yymsp[0].minor);
}
#line 929 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 11: /* exp ::= NUM */
#line 33 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = yymsp[0].minor.yy0.val; }
#line 934 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 12: /* exp ::= exp PLUS exp */
#line 34 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = yymsp[-2].minor.yy68 + yymsp[0].minor.yy68;   yy_destructor(6,&yymsp[-1].minor);
}
#line 940 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 13: /* exp ::= exp MINUS exp */
#line 35 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = yymsp[-2].minor.yy68 - yymsp[0].minor.yy68;   yy_destructor(5,&yymsp[-1].minor);
}
#line 946 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 14: /* exp ::= exp MULTIPLY exp */
#line 36 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = yymsp[-2].minor.yy68 * yymsp[0].minor.yy68;   yy_destructor(7,&yymsp[-1].minor);
}
#line 952 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 15: /* exp ::= exp DIVIDE exp */
#line 37 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ if (yymsp[0].minor.yy68 != 0) yygotominor.yy68 = yymsp[-2].minor.yy68 / yymsp[0].minor.yy68; else context->PrintError("Division by Zero");   yy_destructor(8,&yymsp[-1].minor);
}
#line 958 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 16: /* exp ::= exp OR exp */
#line 38 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = yymsp[-2].minor.yy68 | yymsp[0].minor.yy68;   yy_destructor(2,&yymsp[-1].minor);
}
#line 964 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 17: /* exp ::= exp AND exp */
#line 39 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = yymsp[-2].minor.yy68 & yymsp[0].minor.yy68;   yy_destructor(4,&yymsp[-1].minor);
}
#line 970 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 18: /* exp ::= exp XOR exp */
#line 40 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = yymsp[-2].minor.yy68 ^ yymsp[0].minor.yy68;   yy_destructor(3,&yymsp[-1].minor);
}
#line 976 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 19: /* exp ::= MINUS exp */
#line 41 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = -yymsp[0].minor.yy68;   yy_destructor(5,&yymsp[-1].minor);
}
#line 982 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 20: /* exp ::= LPAREN exp RPAREN */
#line 42 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = yymsp[-1].minor.yy68;   yy_destructor(11,&yymsp[-2].minor);
  yy_destructor(12,&yymsp[0].minor);
}
#line 989 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 21: /* define_statement ::= DEFINE SYM LPAREN exp RPAREN */
#line 52 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	context->AddSym (yymsp[-3].minor.yy0.sym, yymsp[-1].minor.yy68);
  yy_destructor(13,&yymsp[-4].minor);
  yy_destructor(11,&yymsp[-2].minor);
  yy_destructor(12,&yymsp[0].minor);
}
#line 999 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 22: /* enum_statement ::= enum_open enum_list RBRACE */
#line 62 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
  yy_destructor(15,&yymsp[0].minor);
}
#line 1006 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 23: /* enum_open ::= ENUM LBRACE */
#line 65 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	context->EnumVal = 0;
  yy_destructor(16,&yymsp[-1].minor);
  yy_destructor(17,&yymsp[0].minor);
}
#line 1015 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 26: /* enum_list ::= enum_list COMMA single_enum */
#line 71 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1022 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 27: /* single_enum ::= SYM */
#line 74 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	context->AddSym (yymsp[0].minor.yy0.sym, context->EnumVal++);
}
#line 1029 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 28: /* single_enum ::= SYM EQUALS exp */
#line 79 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	context->AddSym (yymsp[-2].minor.yy0.sym, yymsp[0].minor.yy68);
	context->EnumVal = yymsp[0].minor.yy68+1;
  yy_destructor(19,&yymsp[-1].minor);
}
#line 1038 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 29: /* linetype_declaration ::= exp EQUALS exp COMMA exp LPAREN special_args RPAREN */
#line 91 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	SimpleLineTranslations.SetVal(yymsp[-7].minor.yy68, 
		FLineTrans(yymsp[-3].minor.yy68&0xffff, yymsp[-5].minor.yy68+yymsp[-1].minor.yy87.addflags, yymsp[-1].minor.yy87.args[0], yymsp[-1].minor.yy87.args[1], yymsp[-1].minor.yy87.args[2], yymsp[-1].minor.yy87.args[3], yymsp[-1].minor.yy87.args[4]));
  yy_destructor(19,&yymsp[-6].minor);
  yy_destructor(18,&yymsp[-4].minor);
  yy_destructor(11,&yymsp[-2].minor);
  yy_destructor(12,&yymsp[0].minor);
}
#line 1050 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 30: /* linetype_declaration ::= exp EQUALS exp COMMA SYM LPAREN special_args RPAREN */
#line 97 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	Printf ("%s, line %d: %s is undefined\n", context->SourceFile, context->SourceLine, yymsp[-3].minor.yy0.sym);
  yy_destructor(19,&yymsp[-6].minor);
  yy_destructor(18,&yymsp[-4].minor);
  yy_destructor(11,&yymsp[-2].minor);
  yy_destructor(12,&yymsp[0].minor);
}
#line 1061 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 31: /* special_args ::= */
#line 104 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = 0;
	yygotominor.yy87.args[0] = 0;
	yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
}
#line 1073 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 32: /* special_args ::= TAG */
#line 113 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT1;
	yygotominor.yy87.args[0] = 0;
	yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(20,&yymsp[0].minor);
}
#line 1086 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 33: /* special_args ::= TAG COMMA exp */
#line 122 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT1;
	yygotominor.yy87.args[0] = 0;
	yygotominor.yy87.args[1] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(20,&yymsp[-2].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1100 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 34: /* special_args ::= TAG COMMA exp COMMA exp */
#line 131 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT1;
	yygotominor.yy87.args[0] = 0;
	yygotominor.yy87.args[1] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(20,&yymsp[-4].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1115 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 35: /* special_args ::= TAG COMMA exp COMMA exp COMMA exp */
#line 140 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT1;
	yygotominor.yy87.args[0] = 0;
	yygotominor.yy87.args[1] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(20,&yymsp[-6].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1131 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 36: /* special_args ::= TAG COMMA exp COMMA exp COMMA exp COMMA exp */
#line 149 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT1;
	yygotominor.yy87.args[0] = 0;
	yygotominor.yy87.args[1] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[4] = yymsp[0].minor.yy68;
  yy_destructor(20,&yymsp[-8].minor);
  yy_destructor(18,&yymsp[-7].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1148 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 37: /* special_args ::= TAG COMMA TAG */
#line 158 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HAS2TAGS;
	yygotominor.yy87.args[0] = yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(20,&yymsp[-2].minor);
  yy_destructor(18,&yymsp[-1].minor);
  yy_destructor(20,&yymsp[0].minor);
}
#line 1162 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 38: /* special_args ::= TAG COMMA TAG COMMA exp */
#line 166 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HAS2TAGS;
	yygotominor.yy87.args[0] = yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(20,&yymsp[-4].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(20,&yymsp[-2].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1177 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 39: /* special_args ::= TAG COMMA TAG COMMA exp COMMA exp */
#line 174 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HAS2TAGS;
	yygotominor.yy87.args[0] = yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(20,&yymsp[-6].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(20,&yymsp[-4].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1193 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 40: /* special_args ::= TAG COMMA TAG COMMA exp COMMA exp COMMA exp */
#line 182 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HAS2TAGS;
	yygotominor.yy87.args[0] = yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[4] = yymsp[0].minor.yy68;
  yy_destructor(20,&yymsp[-8].minor);
  yy_destructor(18,&yymsp[-7].minor);
  yy_destructor(20,&yymsp[-6].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1210 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 41: /* special_args ::= exp */
#line 190 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = 0;
	yygotominor.yy87.args[0] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
}
#line 1222 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 42: /* special_args ::= exp COMMA exp */
#line 199 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = 0;
	yygotominor.yy87.args[0] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1235 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 43: /* special_args ::= exp COMMA exp COMMA exp */
#line 208 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = 0;
	yygotominor.yy87.args[0] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1249 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 44: /* special_args ::= exp COMMA exp COMMA exp COMMA exp */
#line 217 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = 0;
	yygotominor.yy87.args[0] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1264 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 45: /* special_args ::= exp COMMA exp COMMA exp COMMA exp COMMA exp */
#line 226 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = 0;
	yygotominor.yy87.args[0] = yymsp[-8].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[4] = yymsp[0].minor.yy68;
  yy_destructor(18,&yymsp[-7].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1280 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 46: /* special_args ::= exp COMMA TAG */
#line 235 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT2;
	yygotominor.yy87.args[0] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-1].minor);
  yy_destructor(20,&yymsp[0].minor);
}
#line 1294 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 47: /* special_args ::= exp COMMA TAG COMMA exp */
#line 244 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT2;
	yygotominor.yy87.args[0] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(20,&yymsp[-2].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1309 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 48: /* special_args ::= exp COMMA TAG COMMA exp COMMA exp */
#line 253 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT2;
	yygotominor.yy87.args[0] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(20,&yymsp[-4].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1325 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 49: /* special_args ::= exp COMMA TAG COMMA exp COMMA exp COMMA exp */
#line 262 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT2;
	yygotominor.yy87.args[0] = yymsp[-8].minor.yy68;
	yygotominor.yy87.args[1] = 0;
	yygotominor.yy87.args[2] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[4] = yymsp[0].minor.yy68;
  yy_destructor(18,&yymsp[-7].minor);
  yy_destructor(20,&yymsp[-6].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1342 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 50: /* special_args ::= exp COMMA exp COMMA TAG */
#line 271 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT3;
	yygotominor.yy87.args[0] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
  yy_destructor(20,&yymsp[0].minor);
}
#line 1357 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 51: /* special_args ::= exp COMMA exp COMMA TAG COMMA exp */
#line 280 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT3;
	yygotominor.yy87.args[0] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = yymsp[0].minor.yy68;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(20,&yymsp[-2].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1373 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 52: /* special_args ::= exp COMMA exp COMMA TAG COMMA exp COMMA exp */
#line 289 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT3;
	yygotominor.yy87.args[0] = yymsp[-8].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[2] = 0;
	yygotominor.yy87.args[3] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[4] = yymsp[0].minor.yy68;
  yy_destructor(18,&yymsp[-7].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(20,&yymsp[-4].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1390 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 53: /* special_args ::= exp COMMA exp COMMA exp COMMA TAG */
#line 298 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT4;
	yygotominor.yy87.args[0] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
  yy_destructor(20,&yymsp[0].minor);
}
#line 1406 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 54: /* special_args ::= exp COMMA exp COMMA exp COMMA TAG COMMA exp */
#line 307 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT4;
	yygotominor.yy87.args[0] = yymsp[-8].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[3] = 0;
	yygotominor.yy87.args[4] = yymsp[0].minor.yy68;
  yy_destructor(18,&yymsp[-7].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(20,&yymsp[-2].minor);
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1423 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 55: /* special_args ::= exp COMMA exp COMMA exp COMMA exp COMMA TAG */
#line 316 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy87.addflags = LINETRANS_HASTAGAT5;
	yygotominor.yy87.args[0] = yymsp[-8].minor.yy68;
	yygotominor.yy87.args[1] = yymsp[-6].minor.yy68;
	yygotominor.yy87.args[2] = yymsp[-4].minor.yy68;
	yygotominor.yy87.args[3] = yymsp[-2].minor.yy68;
	yygotominor.yy87.args[4] = 0;
  yy_destructor(18,&yymsp[-7].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(18,&yymsp[-3].minor);
  yy_destructor(18,&yymsp[-1].minor);
  yy_destructor(20,&yymsp[0].minor);
}
#line 1440 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 56: /* boom_declaration ::= LBRACKET exp RBRACKET LPAREN exp COMMA exp RPAREN LBRACE boom_body RBRACE */
#line 341 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	int i;
	MoreLines *probe;

	if (NumBoomish == MAX_BOOMISH)
	{
		MoreLines *probe = yymsp[-1].minor.yy93;

		while (probe != NULL)
		{
			MoreLines *next = probe->next;
			delete probe;
			probe = next;
		}
		Printf ("%s, line %d: Too many BOOM translators\n", context->SourceFile, context->SourceLine);
	}
	else
	{
		Boomish[NumBoomish].FirstLinetype = yymsp[-6].minor.yy68;
		Boomish[NumBoomish].LastLinetype = yymsp[-4].minor.yy68;
		Boomish[NumBoomish].NewSpecial = yymsp[-9].minor.yy68;
		
		for (i = 0, probe = yymsp[-1].minor.yy93; probe != NULL; i++)
		{
			MoreLines *next = probe->next;
			Boomish[NumBoomish].Args.Push(probe->arg);
			delete probe;
			probe = next;
		}
		NumBoomish++;
	}
  yy_destructor(21,&yymsp[-10].minor);
  yy_destructor(22,&yymsp[-8].minor);
  yy_destructor(11,&yymsp[-7].minor);
  yy_destructor(18,&yymsp[-5].minor);
  yy_destructor(12,&yymsp[-3].minor);
  yy_destructor(17,&yymsp[-2].minor);
  yy_destructor(15,&yymsp[0].minor);
}
#line 1483 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 57: /* boom_body ::= */
#line 375 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy93 = NULL;
}
#line 1490 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 58: /* boom_body ::= boom_line boom_body */
#line 379 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy93 = new MoreLines;
	yygotominor.yy93->next = yymsp[0].minor.yy93;
	yygotominor.yy93->arg = yymsp[-1].minor.yy82;
}
#line 1499 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 59: /* boom_line ::= boom_selector boom_op boom_args */
#line 386 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy82.bOrExisting = (yymsp[-1].minor.yy68 == OR_EQUAL);
	yygotominor.yy82.bUseConstant = (yymsp[0].minor.yy7.filters == NULL);
	yygotominor.yy82.ArgNum = yymsp[-2].minor.yy68;
	yygotominor.yy82.ConstantValue = yymsp[0].minor.yy7.constant;
	yygotominor.yy82.AndValue = yymsp[0].minor.yy7.mask;

	if (yymsp[0].minor.yy7.filters != NULL)
	{
		int i;
		MoreFilters *probe;

		for (i = 0, probe = yymsp[0].minor.yy7.filters; probe != NULL; i++)
		{
			MoreFilters *next = probe->next;
			if (i < 15)
			{
				yygotominor.yy82.ResultFilter[i] = probe->filter.filter;
				yygotominor.yy82.ResultValue[i] = probe->filter.value;
			}
			else if (i == 15)
			{
				context->PrintError ("Lists can only have 15 elements");
			}
			delete probe;
			probe = next;
		}
		yygotominor.yy82.ListSize = i > 15 ? 15 : i;
	}
}
#line 1533 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 60: /* boom_selector ::= FLAGS */
#line 417 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = 4;   yy_destructor(23,&yymsp[0].minor);
}
#line 1539 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 61: /* boom_selector ::= ARG2 */
#line 418 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = 0;   yy_destructor(24,&yymsp[0].minor);
}
#line 1545 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 62: /* boom_selector ::= ARG3 */
#line 419 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = 1;   yy_destructor(25,&yymsp[0].minor);
}
#line 1551 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 63: /* boom_selector ::= ARG4 */
#line 420 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = 2;   yy_destructor(26,&yymsp[0].minor);
}
#line 1557 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 64: /* boom_selector ::= ARG5 */
#line 421 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = 3;   yy_destructor(27,&yymsp[0].minor);
}
#line 1563 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 65: /* boom_op ::= EQUALS */
#line 423 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = '=';   yy_destructor(19,&yymsp[0].minor);
}
#line 1569 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 66: /* boom_op ::= OR_EQUAL */
#line 424 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = OR_EQUAL;   yy_destructor(28,&yymsp[0].minor);
}
#line 1575 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 67: /* boom_args ::= exp */
#line 427 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy7.constant = yymsp[0].minor.yy68;
	yygotominor.yy7.filters = NULL;
}
#line 1583 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 68: /* boom_args ::= exp LBRACKET arg_list RBRACKET */
#line 432 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy7.mask = yymsp[-3].minor.yy68;
	yygotominor.yy7.filters = yymsp[-1].minor.yy51;
  yy_destructor(21,&yymsp[-2].minor);
  yy_destructor(22,&yymsp[0].minor);
}
#line 1593 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 69: /* arg_list ::= list_val */
#line 438 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy51 = new MoreFilters;
	yygotominor.yy51->next = NULL;
	yygotominor.yy51->filter = yymsp[0].minor.yy3;
}
#line 1602 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 70: /* arg_list ::= list_val COMMA arg_list */
#line 444 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy51 = new MoreFilters;
	yygotominor.yy51->next = yymsp[0].minor.yy51;
	yygotominor.yy51->filter = yymsp[-2].minor.yy3;
  yy_destructor(18,&yymsp[-1].minor);
}
#line 1612 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 71: /* list_val ::= exp COLON exp */
#line 451 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	yygotominor.yy3.filter = yymsp[-2].minor.yy68;
	yygotominor.yy3.value = yymsp[0].minor.yy68;
  yy_destructor(29,&yymsp[-1].minor);
}
#line 1621 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 72: /* maxlinespecial_def ::= MAXLINESPECIAL EQUALS exp SEMICOLON */
#line 463 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	// Just kill all specials higher than the max.
	// If the translator wants to redefine some later, just let it.s
	SimpleLineTranslations.Resize(yymsp[-1].minor.yy68+1);
  yy_destructor(30,&yymsp[-3].minor);
  yy_destructor(19,&yymsp[-2].minor);
  yy_destructor(31,&yymsp[0].minor);
}
#line 1633 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 73: /* sector_declaration ::= SECTOR exp EQUALS exp SEMICOLON */
#line 478 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	FSectorTrans tr(yymsp[-1].minor.yy68, true);
	SectorTranslations.SetVal(yymsp[-3].minor.yy68, tr);
  yy_destructor(32,&yymsp[-4].minor);
  yy_destructor(19,&yymsp[-2].minor);
  yy_destructor(31,&yymsp[0].minor);
}
#line 1644 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 74: /* sector_declaration ::= SECTOR exp EQUALS SYM SEMICOLON */
#line 484 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	Printf("Unknown constant '%s'\n", yymsp[-1].minor.yy0.sym);
  yy_destructor(32,&yymsp[-4].minor);
  yy_destructor(19,&yymsp[-2].minor);
  yy_destructor(31,&yymsp[0].minor);
}
#line 1654 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 75: /* sector_declaration ::= SECTOR exp EQUALS exp NOBITMASK SEMICOLON */
#line 489 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	FSectorTrans tr(yymsp[-2].minor.yy68, false);
	SectorTranslations.SetVal(yymsp[-4].minor.yy68, tr);
  yy_destructor(32,&yymsp[-5].minor);
  yy_destructor(19,&yymsp[-3].minor);
  yy_destructor(33,&yymsp[-1].minor);
  yy_destructor(31,&yymsp[0].minor);
}
#line 1666 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 76: /* sector_bitmask ::= SECTOR BITMASK exp sector_op exp SEMICOLON */
#line 495 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	FSectorMask sm = { yymsp[-3].minor.yy68, yymsp[-2].minor.yy68, yymsp[-1].minor.yy68};
	SectorMasks.Push(sm);
  yy_destructor(32,&yymsp[-5].minor);
  yy_destructor(34,&yymsp[-4].minor);
  yy_destructor(31,&yymsp[0].minor);
}
#line 1677 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 77: /* sector_bitmask ::= SECTOR BITMASK exp SEMICOLON */
#line 501 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	FSectorMask sm = { yymsp[-1].minor.yy68, 0, 0};
	SectorMasks.Push(sm);
  yy_destructor(32,&yymsp[-3].minor);
  yy_destructor(34,&yymsp[-2].minor);
  yy_destructor(31,&yymsp[0].minor);
}
#line 1688 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 78: /* sector_bitmask ::= SECTOR BITMASK exp CLEAR SEMICOLON */
#line 507 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{
	FSectorMask sm = { yymsp[-2].minor.yy68, 0, 1};
	SectorMasks.Push(sm);
  yy_destructor(32,&yymsp[-4].minor);
  yy_destructor(34,&yymsp[-3].minor);
  yy_destructor(35,&yymsp[-1].minor);
  yy_destructor(31,&yymsp[0].minor);
}
#line 1700 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 79: /* sector_op ::= LSHASSIGN */
#line 512 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = 1;   yy_destructor(36,&yymsp[0].minor);
}
#line 1706 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
      case 80: /* sector_op ::= RSHASSIGN */
#line 513 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
{ yygotominor.yy68 = -1;   yy_destructor(37,&yymsp[0].minor);
}
#line 1712 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
        break;
  };
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yypParser->yyidx -= yysize;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,yygoto);
  if( yyact < YYNSTATE ){
#ifdef NDEBUG
    /* If we are not debugging and the reduce action popped at least
    ** one element off the stack, then we can push the new element back
    ** onto the stack here, and skip the stack overflow test in yy_shift().
    ** That gives a significant speed improvement. */
    if( yysize ){
      yypParser->yyidx++;
      yymsp -= yysize-1;
      yymsp->stateno = yyact;
      yymsp->major = yygoto;
      yymsp->minor = yygotominor;
    }else
#endif
    {
      yy_shift(yypParser,yyact,yygoto,&yygotominor);
    }
  }else{
    assert( yyact == YYNSTATE + YYNRULE + 1 );
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  XlatParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
  XlatParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  YYMINORTYPE yyminor            /* The minor type of the error token */
){
  XlatParseARG_FETCH;
#define TOKEN (yyminor.yy0)
#line 7 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.y"
 context->PrintError("syntax error");
#line 1772 "c:\\Users\\charlesjacobi\\Documents\\Visual Studio 2008\\Projects\\Chex3\\src\\xlat\\xlat_parser.c"
  XlatParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  XlatParseARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
  XlatParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "XlatParseAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void XlatParse(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  XlatParseTOKENTYPE yyminor       /* The value for the token */
  XlatParseARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  int yyact;            /* The parser action. */
  int yyendofinput;     /* True if we are at the end of input */
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  /* (re)initialize the parser, if necessary */
  yypParser = (yyParser*)yyp;
  if( yypParser->yyidx<0 ){
#if YYSTACKDEPTH<=0
    if( yypParser->yystksz <=0 ){
      memset(&yyminorunion, 0, sizeof(yyminorunion));
      yyStackOverflow(yypParser, &yyminorunion);
      return;
    }
#endif
    yypParser->yyidx = 0;
    yypParser->yyerrcnt = -1;
    yypParser->yystack[0].stateno = 0;
    yypParser->yystack[0].major = 0;
  }
  yyminorunion.yy0 = yyminor;
  yyendofinput = (yymajor==0);
  XlatParseARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput %s\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,yymajor);
    if( yyact<YYNSTATE ){
      assert( !yyendofinput );  /* Impossible to shift the $ token */
      yy_shift(yypParser,yyact,yymajor,&yyminorunion);
      yypParser->yyerrcnt--;
      yymajor = YYNOCODE;
    }else if( yyact < YYNSTATE + YYNRULE ){
      yy_reduce(yypParser,yyact-YYNSTATE);
    }else{
#ifdef YYERRORSYMBOL
      int yymx;
#endif
      assert( yyact == YY_ERROR_ACTION );
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yymx = yypParser->yystack[yypParser->yyidx].major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yymajor,&yyminorunion);
        yymajor = YYNOCODE;
      }else{
         while(
          yypParser->yyidx >= 0 &&
          yymx != YYERRORSYMBOL &&
          (yyact = yy_find_reduce_action(
                        yypParser->yystack[yypParser->yyidx].stateno,
                        YYERRORSYMBOL)) >= YYNSTATE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yyidx < 0 || yymajor==0 ){
          yy_destructor(yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          YYMINORTYPE u2;
          u2.YYERRSYMDT = 0;
          yy_shift(yypParser,yyact,YYERRORSYMBOL,&u2);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor,yyminorunion);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yyidx>=0 );
  return;
}
